@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 from GSettingsWidgets import *
 from ChooserButtonWidgets import TweenChooserButton, EffectChooserButton
@@ -22,7 +22,7 @@ TRANSITIONS_SETS = {
 }
 
 TIME_SETS = {
-    "cinnamon": (175, 175, 200, 100, 100, 100),
+    "cinnamon": (100, 120, 160, 100, 100, 100),
     "slow":     (400, 400, 400, 100, 100, 100),
     "normal":   (250, 250, 250, 100, 100, 100),
     "fast":     (100, 100, 100, 100, 100, 100),
@@ -30,7 +30,7 @@ TIME_SETS = {
 }
 
 COMBINATIONS = {
-   #  name           effect    transition    time
+    #  name           effect    transition    time
     "cinnamon":   ("cinnamon", "cinnamon", "cinnamon"),
     "scale":      ("scale",    "normal",   "normal"),
     "fancyScale": ("scale",    "extra",    "slow"),
@@ -39,7 +39,7 @@ COMBINATIONS = {
     "move":       ("move",     "normal",   "fast"),
     "flyUp":      ("flyUp",    "normal",   "fast"),
     "flyDown":    ("flyDown",  "normal",   "fast"),
-   #for previous versions
+    #for previous versions
     "default":    ("default",  "normal",   "default")
 }
 
@@ -52,7 +52,7 @@ OPTIONS = (
     ("move",       _("Move")),
     ("flyUp",      _("Fly up, down")),
     ("flyDown",    _("Fly down, up")),
-   #for previous versions
+    #for previous versions
     ("default",    _("Default"))
 )
 TYPES = ("map", "close", "minimize", "maximize", "unmaximize", "tile")
@@ -67,7 +67,7 @@ class GSettingsTweenChooserButton(TweenChooserButton, CSGSettingsBackend):
         self.bind_dir = Gio.SettingsBindFlags.DEFAULT
         self.bind_object = self
 
-        if schema not in settings_objects.keys():
+        if schema not in settings_objects:
             settings_objects[schema] = Gio.Settings.new(schema)
         self.settings = settings_objects[schema]
 
@@ -81,7 +81,7 @@ class GSettingsEffectChooserButton(EffectChooserButton, CSGSettingsBackend):
         self.bind_dir = Gio.SettingsBindFlags.DEFAULT
         self.bind_object = self
 
-        if schema not in settings_objects.keys():
+        if schema not in settings_objects:
             settings_objects[schema] = Gio.Settings.new(schema)
         self.settings = settings_objects[schema]
 
@@ -100,7 +100,7 @@ class Module:
 
     def on_module_selected(self):
         if not self.loaded:
-            print "Loading Effects module"
+            print("Loading Effects module")
 
             self.sidePage.stack = SettingsStack()
             self.sidePage.add_widget(self.sidePage.stack)
@@ -197,10 +197,11 @@ class Module:
     def make_effect_group(self, group_label, key, effects=None):
         tmin, tmax, tstep, tdefault = (0, 2000, 50, 200)
 
-        row =SettingsWidget()
+        row = SettingsWidget()
         row.set_spacing(5)
 
-        label = Gtk.Label()
+        label = SettingsLabel()
+        label.set_margin_right(5)
         label.set_markup(group_label)
         label.props.xalign = 0.0
         row.pack_start(label, False, False, 0)
