@@ -1,7 +1,7 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
 // Copyright (C) 2011 Giovanni Campagna
-// Copyright (C) 2013-2014 Jonas Kümmerlin <rgcjonas@gmail.com>
+// Copyright (C) 2013-2014 Jonas Kummerlin <rgcjonas@gmail.com>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -407,7 +407,7 @@ AppIndicator.prototype = {
     },
 
     get label() {
-        if (!this._proxy)
+        if (!this._proxy || !this._proxy.cachedProperties.XAyatanaLabel)
             return null;
         return this._proxy.cachedProperties.XAyatanaLabel;
     },
@@ -516,7 +516,7 @@ AppIndicator.prototype = {
                     global.logWarning("Incompatible dbusmenu version: "+version);
                     return callback(false);
                 }
-            }, null
+            }
         );
     },
 
@@ -581,6 +581,16 @@ AppIndicator.prototype = {
         }
     },
 
+    secondaryActivate: function() {
+        if (this._proxy) {
+            let test = this._proxy.call({
+                name: 'SecondaryActivate',
+                paramTypes: 'ii',
+                paramValues: [0, 0]
+            });
+        }
+    },
+
     scroll: function(dx, dy) {
         if (this._proxy) {
             if (dx != 0) {
@@ -965,7 +975,7 @@ IndicatorActor.prototype = {
         this._iconSize = size;
         this._iconCache = new IconCache();
         this._mainIcon = new St.Bin();
-        this._overlayIcon = new St.Bin({ 'x-align': St.Align.END, 'y-align': St.Align.END });
+        this._overlayIcon = new St.Bin();
         this._label = new St.Label({'y-align': St.Align.END });//FIXME: We need an style class for the label.
 
         this.actor.add_actor(this._mainIcon);
@@ -975,9 +985,9 @@ IndicatorActor.prototype = {
         this._updatedLabel();
         this._updatedStatus();
 
-        this._signalManager = new SignalManager.SignalManager(this);
-        this._signalManager.connect(this.actor, 'scroll-event', this._handleScrollEvent);
-        this._signalManager.connect(Gtk.IconTheme.get_default(), 'changed', this._invalidateIcon);
+        this._signalManager = new SignalManager.SignalManager(null);
+        this._signalManager.connect(this.actor, 'scroll-event', this._handleScrollEvent, this);
+        this._signalManager.connect(Gtk.IconTheme.get_default(), 'changed', this._invalidateIcon, this);
         //this._signalManager.connect(this._indicator, 'icon', this._updateIcon);
         //this._signalManager.connect(this._indicator, 'overlay-icon', this._updateOverlayIcon);
         //this._signalManager.connect(this._indicator, 'ready', this._invalidateIcon);
@@ -1046,10 +1056,12 @@ IndicatorActor.prototype = {
     },
 
     _updatedLabel: function() {
-        if (this._indicator.label != undefined)
+        if (this._indicator.label != undefined) {
             this._label.set_text(this._indicator.label);
-        else
+        } else {
             this._label.set_text("");
+            this.actor.remove_style_class_name('applet-box');
+        }
     },
 
     // FIXME: When an indicator is in passive state, the recommended behavior is hide his actor,
@@ -1108,9 +1120,13 @@ IndicatorActor.prototype = {
             } else if (event.get_button() == 1) {
                 this.menu.close();
                 this._indicator.open();
+            }else if (event.get_button() == 2) {
+                this._indicator.secondaryActivate();
             }
         } else if ((event.get_button() == 1) && this.menu) {
             this.menu.toggle();
+        } else if ((event.get_button() == 2) && this.menu) {
+            this._indicator.secondaryActivate();
         }
         return false;
     },
@@ -1203,8 +1219,9 @@ IndicatorActor.prototype = {
     _createIconByName: function(path, iconSize) {
         try {
             let pixbuf = GdkPixbuf.Pixbuf.new_from_file(path);
-            let icon = new St.Icon({ 
-                style_class: 'applet-icon',//FIXME: Use instead the status icon style class.
+            let icon = new St.Icon({
+                name: 'CinnamonTrayIcon',
+                style_class: '',//FIXME: Use instead the status icon style class.
                 gicon: pixbuf,
             });
             if (iconSize)
